
在之前的UI布局代码中，每修改一次布局，布局代码就被重置了，在布局代码中添加的部分又得重新设置了，需求总是变化，界面调整次数多了，每次重新设置还是挺让人头痛。为了解决这个麻烦问题，于是我重新设计了代码架构。

参照了后端开发中常用的 MVC 架构，我将代码重新分为了四个部分，程序入口、UI、窗口控制器、服务。
这样每一层的变化都不会影响下一层，如果UI布局发生了变化，只需替换UI文件即可。

## 代码示例

当前示例项目，分为三个文件 main.py ，ui.py， controller.py

分别是入口文件、界面文件，界面控制器。

### 界面文件
将布局助手上，界面文件代码复制下来就行。此文件复制下拉后最好就不要编辑了，以后如果布局代码有变换，将布局助手上代码复制下拉替换即可

### 界面控制器
一般情况下，一个布局文件，对应一个界面控制器。界面控制器，主要负责组件的初始化，在这可以给组件赋值，获取组件值，绑定事件等。创建布局文件时，从布局助手上复制下代码，粘贴到你的控制器文件即可，在布局助手上添加或者编辑组件的事件后，只复制生成的事件名称到你的控制器文件即可。

```python
class Controller:
    # 导入UI类后，替换以下的 object 类型，将获得 IDE 属性提示功能
    ui: object
    def __init__(self):
        pass
    def init(self, ui):
        """
        得到UI实例，对组件进行初始化配置
        """
        self.ui = ui
        # TODO 组件初始化 赋值操作

    # 第一次创建布局控制器文件的时候，复制全部代码，后续有编辑改动，复制此行以下新增的方法代码即可。

```

### 入口文件

在入库文件里面，需将布局文件、以及布局控制器导入，在此文件运行整个项目。

```python
from controller import Controller
from ui import Win

if __name__ == '__main__':
    app = Win(Controller())
    app.mainloop()

```

## 更多说明 请看代码中的注释